@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 ## src/common/helpers.py
 ##
-## Copyright (C) 2003-2014 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2003-2017 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
 ##                         Nikos Kouremenos <kourem AT gmail.com>
 ## Copyright (C) 2006 Alex Mauer <hawke AT hawkesnest.net>
@@ -46,6 +46,7 @@ import shlex
 import caps_cache
 import socket
 import time
+import datetime
 
 from encodings.punycode import punycode_encode
 from string import Template
@@ -144,8 +145,12 @@ def puny_encode_url(url):
     _url = url
     if '//' not in _url:
         _url = '//' + _url
-    o = urlparse(_url)
-    p_loc = idn_to_ascii(o.netloc)
+    try:
+        o = urlparse(_url)
+        p_loc = idn_to_ascii(o.netloc)
+    except:
+        log.debug('urlparse failed: %s', url)
+        return False
     return url.replace(o.netloc, p_loc)
 
 def parse_resource(resource):
@@ -400,7 +405,7 @@ def is_in_path(command, return_abs_path=False):
             pass
     return False
 
-def exec_command(command, use_shell=False):
+def exec_command(command, use_shell=False, posix=True):
     """
     execute a command. if use_shell is True, we run the command as is it was
     typed in a console. So it may be dangerous if you are not sure about what
@@ -409,7 +414,7 @@ def exec_command(command, use_shell=False):
     if use_shell:
         subprocess.Popen('%s &' % command, shell=True).wait()
     else:
-        args = shlex.split(command.encode('utf-8'))
+        args = shlex.split(command.encode('utf-8'), posix=posix)
         p = subprocess.Popen(args)
         gajim.thread_interface(p.wait)
 
@@ -628,12 +633,30 @@ def datetime_tuple(timestamp):
             - XEP-082 datetime strings have all '-' cahrs removed to meet
               the above format.
     """
-    timestamp = timestamp.split('.')[0]
-    timestamp = timestamp.replace('-', '')
-    timestamp = timestamp.replace('z', '')
-    timestamp = timestamp.replace('Z', '')
-    from time import strptime
-    return strptime(timestamp, '%Y%m%dT%H:%M:%S')
+    date, tim = timestamp.split('T', 1)
+    date = date.replace('-', '')
+    tim = tim.replace('z', '')
+    tim = tim.replace('Z', '')
+    zone = None
+    if '+' in tim:
+        sign = -1
+        tim, zone = tim.split('+', 1)
+    if '-' in tim:
+        sign = 1
+        tim, zone = tim.split('-', 1)
+    tim = tim.split('.')[0]
+    tim = time.strptime(date + 'T' + tim, '%Y%m%dT%H:%M:%S')
+    if zone:
+        zone = zone.replace(':', '')
+        tim = datetime.datetime.fromtimestamp(time.mktime(tim))
+        if len(zone) > 2:
+            zone = time.strptime(zone, '%H%M')
+        else:
+            zone = time.strptime(zone, '%H')
+        zone = datetime.timedelta(hours=zone.tm_hour, minutes=zone.tm_min)
+        tim += zone * sign
+        tim = tim.timetuple()
+    return tim
 
 # import gajim only when needed (after decode_string is defined) see #4764
 
@@ -1295,9 +1318,9 @@ def prepare_and_validate_gpg_keyID(account, jid, keyID):
             # An unsigned presence, just use the assigned key
             keyID = attached_keys[attached_keys.index(jid) + 1]
         elif keyID:
-            public_keys = gajim.connections[account].ask_gpg_keys()
+            full_key = gajim.connections[account].ask_gpg_keys(keyID=keyID)
             # Assign the corresponding key, if we have it in our keyring
-            if keyID in public_keys:
+            if full_key:
                 for u in gajim.contacts.get_contacts(account, jid):
                     u.keyID = keyID
                 keys_str = gajim.config.get_per('accounts', account,
@@ -1459,9 +1482,11 @@ def _get_img_direct(attrs):
     """
     Download an image. This function should be launched in a separated thread.
     """
-    mem, alt = '', ''
-    # Wait maximum 5s for connection
-    socket.setdefaulttimeout(5)
+    mem, alt, max_size = '', '', 2*1024*1024
+    if 'max_size' in attrs:
+        max_size = attrs['max_size']
+    # Wait maximum 10s for connection
+    socket.setdefaulttimeout(10)
     try:
         req = urllib2.Request(attrs['src'])
         req.add_header('User-Agent', 'Gajim ' + gajim.version)
@@ -1471,13 +1496,13 @@ def _get_img_direct(attrs):
         pixbuf = None
         alt = attrs.get('alt', 'Broken image')
     else:
-        # Wait 0.5s between each byte
+        # Wait 2s between each byte
         try:
-            f.fp._sock.fp._sock.settimeout(0.5)
+            f.fp._sock.fp._sock.settimeout(2)
         except Exception:
             pass
-        # Max image size = 2 MB (to try to prevent DoS)
-        deadline = time.time() + 3
+        # On a slow internet connection with ~1000kbps you need ~10 seconds for 1 MB
+        deadline = time.time() + (10 * (max_size / 1048576))
         while True:
             if time.time() > deadline:
                 log.debug('Timeout loading image %s ' % attrs['src'])
@@ -1500,7 +1525,7 @@ def _get_img_direct(attrs):
                 mem += temp
             else:
                 break
-            if len(mem) > 2*1024*1024:
+            if len(mem) > max_size:
                 alt = attrs.get('alt', '')
                 if alt:
                     alt += '\n'
@@ -1515,15 +1540,19 @@ def _get_img_proxy(attrs, proxy):
     """
     if not gajim.HAVE_PYCURL:
         return '', _('PyCURL is not installed')
-    mem, alt = '', ''
+    mem, alt, max_size = '', '', 2*1024*1024
+    if 'max_size' in attrs:
+        max_size = attrs['max_size']
     try:
         b = StringIO()
         c = pycurl.Curl()
         c.setopt(pycurl.URL, attrs['src'].encode('utf-8'))
         c.setopt(pycurl.FOLLOWLOCATION, 1)
-        c.setopt(pycurl.CONNECTTIMEOUT, 5)
-        c.setopt(pycurl.TIMEOUT, 10)
-        c.setopt(pycurl.MAXFILESIZE, 2000000)
+        # Wait maximum 10s for connection
+        c.setopt(pycurl.CONNECTTIMEOUT, 10)
+        # On a slow internet connection with ~1000kbps you need ~10 seconds for 1 MB
+        c.setopt(pycurl.TIMEOUT, 10 * (max_size / 1048576))
+        c.setopt(pycurl.MAXFILESIZE, max_size)
         c.setopt(pycurl.WRITEFUNCTION, b.write)
         c.setopt(pycurl.USERAGENT, 'Gajim ' + gajim.version)
         # set proxy
