@@ -3,7 +3,7 @@
 ##
 ## Copyright (C) 2006 Gustavo Carneiro <gjcarneiro AT gmail.com>
 ##                    Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2012 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2006-2017 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2008 Jean-Marie Traissard <jim AT lapin.org>
 ##                    Jonathan Schleifer <js-gajim AT webkeks.org>
 ##                    Stephan Erb <steve-e AT h3c.de>
@@ -198,7 +198,7 @@ class MusicTrackListener(gobject.GObject):
         info.title = props.get('title', None)
         info.album = props.get('album', None)
         info.artist = props.get('artist', None)
-        info.duration = int(props.get('~#length', 0))
+        info.duration = float(props.get('~#length', 0))
         return info
 
     def get_playing_track(self):
